pub struct ByteOrder {
pub byte_order: ByteOrderEnum,
/* private fields */
}Expand description
Where the standard value does not apply this parameter can be used to specify the byte order
Specification: 3.5.24
Fields
byte_order: ByteOrderEnumImplementations