ItemList

Struct ItemList 

pub struct ItemList<T: A2lObjectName> { /* private fields */ }
A list of named a2l items

An ItemList is an ordered collection of items, which additionally allows for fast access to items by their name.

Implementations

Source

impl<T: A2lObjectName> ItemList<T>

pub fn new() -> Self

create a new ItemList

pub fn with_capacity(capacity: usize) -> Self

create a new ItemList with a specified initial capacity

pub fn push(&mut self, value: T)

push an item into the ItemList

pub fn push_unique(&mut self, value: T)

push an item into the ItemList, replacing any existing item with the same name

pub fn pop(&mut self) -> Option<T>

pop an item from the ItemList

pub fn get(&self, key: &str) -> Option<&T>

get an item by key

pub fn get_mut(&mut self, key: &str) -> Option<&mut T>

get a mutable reference to an item by key

pub fn first(&self) -> Option<&T>

get the first item in the ItemList

pub fn last(&self) -> Option<&T>

get the last item in the ItemList

pub fn index(&self, key: &str) -> Option<usize>

get the index of an item by key

pub fn contains_key(&self, key: &str) -> bool

Checks if the ItemList contains an item with the given key

pub fn swap_remove(&mut self, key: &str) -> Option<T>

remove an item from the ItemList by key and return it

pub fn swap_remove_idx(&mut self, index: usize) -> Option<T>

remove an item from the ItemList by index and return it

pub fn iter(&self) -> impl Iterator<Item = &T>

Returns an iterator over references to the items in the ItemList

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut T>

Returns an iterator over mutable references to the items in the ItemList

pub fn keys(&self) -> impl Iterator<Item = &String>

Returns an iterator over the keys in the ItemList

pub fn len(&self) -> usize

Returns the number of items in the ItemList

pub fn is_empty(&self) -> bool

Checks if the ItemList is empty

pub fn extend<I>(&mut self, iter: I)
where I: IntoIterator<Item = T>,

extend the ItemList from an iterator

pub fn clear(&mut self)

remove all items from the ItemList

pub fn truncate(&mut self, len: usize)

trucate the ItemList to a specified length

pub fn retain<F>(&mut self, keep: F)
where F: FnMut(&mut T) -> bool,

Selectively remove or retain items from the ItemList based on a predicate function

pub fn sort_by<F>(&mut self, cmp: F)
where F: FnMut(&T, &T) -> Ordering,

Source

impl<T: A2lObjectName + A2lObjectNameSetter> ItemList<T>

pub fn rename_item(&mut self, item_idx: usize, new_name: &str)

Set the name of an item in the ItemList