Struct a2lfile::StatusStringRef
source · pub struct StatusStringRef {
pub conversion_table: String,
/* private fields */
}Expand description
used to split up the value range of ECU internal values into a numerical and a verbal part
Fields
conversion_table: StringImplementations